from .hylightpy import HIAtom
from importlib.metadata import version

__version__ = version("hylightpy")
